@@ -7,8 +7,12 @@
 #include "qmlanchorbindingproxy.h"
 #include "qmlmodelnodeproxy.h"
 
+#include <utils/uniqueobjectptr.h>
+
 #include <nodemetainfo.h>
 
+#include <memory>
+
 class PropertyEditorValue;
 
 QT_BEGIN_NAMESPACE
@@ -27,19 +31,20 @@ class TextureEditorQmlBackend
     Q_DISABLE_COPY(TextureEditorQmlBackend)
 
 public:
-    TextureEditorQmlBackend(TextureEditorView *materialEditor,
+    TextureEditorQmlBackend(TextureEditorView *textureEditor,
                             class AsynchronousImageCache &imageCache);
     ~TextureEditorQmlBackend();
 
     void setup(const QmlObjectNode &selectedTextureNode, const QString &stateName, const QUrl &qmlSpecificsFile,
                TextureEditorView *textureEditor);
-    void setValue(const QmlObjectNode &fxObjectNode, const PropertyName &name, const QVariant &value);
+    void setValue(const QmlObjectNode &fxObjectNode, PropertyNameView name, const QVariant &value);
+    void setExpression(PropertyNameView propName, const QString &exp);
 
     QQmlContext *context() const;
     TextureEditorContextObject *contextObject() const;
     QQuickWidget *widget() const;
     void setSource(const QUrl &url);
-    Internal::QmlAnchorBindingProxy &backendAnchorBinding();
+    QmlAnchorBindingProxy &backendAnchorBinding();
     DesignerPropertyMap &backendValuesPropertyMap();
     TextureEditorTransaction *textureEditorTransaction() const;
 
@@ -54,16 +59,20 @@ public:
 
 private:
     void createPropertyEditorValue(const QmlObjectNode &qmlObjectNode,
-                                   const PropertyName &name, const QVariant &value,
+                                   PropertyNameView name,
+                                   const QVariant &value,
                                    TextureEditorView *textureEditor);
-    PropertyName auxNamePostFix(const PropertyName &propertyName);
+    PropertyName auxNamePostFix(PropertyNameView propertyName);
 
-    QQuickWidget *m_view = nullptr;
-    Internal::QmlAnchorBindingProxy m_backendAnchorBinding;
-    QmlModelNodeProxy m_backendModelNode;
+    // to avoid a crash while destructing DesignerPropertyMap in the QQmlData
+    // this needs be destructed after m_quickWidget->engine() is destructed
     DesignerPropertyMap m_backendValuesPropertyMap;
-    QScopedPointer<TextureEditorTransaction> m_textureEditorTransaction;
-    QScopedPointer<TextureEditorContextObject> m_contextObject;
+
+    Utils::UniqueObjectPtr<QQuickWidget> m_quickWidget;
+    QmlAnchorBindingProxy m_backendAnchorBinding;
+    QmlModelNodeProxy m_backendModelNode;
+    std::unique_ptr<TextureEditorTransaction> m_textureEditorTransaction;
+    std::unique_ptr<TextureEditorContextObject> m_contextObject;
     AssetImageProvider *m_textureEditorImageProvider = nullptr;
 };
 
